<!-- markdownlint-disable -->

<a href="..\..\qtstrap\utils\signals.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.signals`






---

<a href="..\..\qtstrap\utils\signals.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `SignalBlocker`
A context manager that blocks the signals of the provided widget. 

The signals are unblocked at the end of the with block. 

<a href="..\..\qtstrap\utils\signals.py#L9"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `SignalBlocker.__init__`

```python
__init__(widget)
```











---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
